#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright @2024 AI. Inspur Inc.
#
# @author: suojiayi <suojiayi@inspur.com>
# @date: 2025/05/13

import json
import re

def is_empty(value):
    """
    判断一个值是否为空（包括 None、空字符串、空列表、空字典等）
    :param value: 检查的值
    :return: 如果值为空则返回 True，否则返回 False
    """
    if value is None:
        return True
    if isinstance(value, str) and not value.strip():
        return True
    if isinstance(value, (list, dict)) and len(value) == 0:
        return True
    return False


def filter_empty_fields(data):
    """
    递归过滤 JSON 数据中的空字段数据项
    :param data: 当前处理的数据（可以是 dict、list）
    :return: 过滤后的数据
    """
    if isinstance(data, list):
        filtered_list = [filter_empty_fields(item) for item in data if not is_empty(item)]
        return [item for item in filtered_list if not is_empty(item)]
    elif isinstance(data, dict):
        filtered_dict = {k: filter_empty_fields(v) for k, v in data.items() if not is_empty(v)}
        final_dict = {k: v for k, v in filtered_dict.items() if not is_empty(v)}
        if not final_dict:
            return None
        return final_dict
    else:
        return data

def process_jsonl(input_file, output_file):
    with open(input_file, 'r', encoding='utf-8') as fin, open(output_file, 'w', encoding='utf-8') as fout:
        for line in fin:
            data = json.loads(line.strip())['data']

            last_user = None
            last_assistant = None
            history = []

            for i in range(len(data)):
                if data[i]['role'] == 'user':
                    if i + 1 < len(data) and data[i+1]['role'] == 'assistant':
                        history.append([data[i]['content'], data[i+1]['content']])
                    else:
                        last_user = data[i]['content']
                elif data[i]['role'] == 'assistant' and data[i-1]['role'] != 'user':
                    pass

            input_content = last_user or (data[-2]['content'] if len(data) >= 2 and data[-1]['role'] == 'assistant' else "")
            output_content = data[-1]['content'] if data[-1]['role'] == 'assistant' else ""
            if output_content:
                target_pattern = "问题："
                output_content = re.sub(target_pattern, "", output_content)
                if output_content:
                    result = {
                        "input": input_content,
                        "output": output_content,
                        "history": history[:-1] if history and input_content in history[-1] else history
                    }

                    result = filter_empty_fields(result)

                    fout.write(json.dumps(result, ensure_ascii=False) + '\n')


# input_file = './dhbq/merged_result.jsonl'
# output_file = './dhbq/train_data_0506.jsonl'
# process_jsonl(input_file, output_file)

input_file = './dhbq/test_data.jsonl'
output_file = './dhbq/test_data_0512.jsonl'
process_jsonl(input_file, output_file)